2024-09-06 Version: 7.1.1
- Update API GetPrometheusInstance: update response param.


2024-09-06 Version: 7.1.0
- Support API GetAgentDownloadUrlV2.
- Update API CreateRumApp: add param RealRegionId.
- Update API DeleteRumApp: add param RealRegionId.
- Update API GetPrometheusInstance: update response param.
- Update API ListActivatedAlerts: update response param.
- Update API ListAlerts: update response param.
- Update API UpdatePrometheusInstance: add param AuthFreeReadPolicy.
- Update API UpdatePrometheusInstance: add param AuthFreeWritePolicy.
- Update API UpdatePrometheusInstance: add param EnableAuthFreeRead.
- Update API UpdatePrometheusInstance: add param EnableAuthFreeWrite.
- Update API UpdatePrometheusInstance: add param EnableAuthToken.
- Update API UpdateRumApp: add param RealRegionId.


2024-08-23 Version: 7.0.4
- Generated python 2019-08-08 for ARMS.

2024-08-21 Version: 7.0.3
- Generated python 2019-08-08 for ARMS.

2024-08-16 Version: 7.0.2
- Update API CreateRumUploadFileUrl: update param FileName.
- Update API CreateRumUploadFileUrl: update param Pid.
- Update API GetMultipleTrace: update param EndTime.
- Update API GetMultipleTrace: update param StartTime.
- Update API GetRumAppInfo: update param Pid.
- Update API GetRumDataForPage: update param EndTime.
- Update API GetRumDataForPage: update param Query.
- Update API GetRumDataForPage: update param StartTime.
- Update API GetRumOcuStatisticData: update param EndTime.
- Update API GetRumOcuStatisticData: update param Page.
- Update API GetRumOcuStatisticData: update param PageSize.
- Update API GetRumOcuStatisticData: update param StartTime.
- Update API GetRumUploadFiles: update param Pid.


2024-08-15 Version: 7.0.1
- Update API DeleteRumUploadFile: add param BatchItems.
- Update API DeleteRumUploadFile: update param Pid.


2024-08-15 Version: 7.0.0
- Delete API AddPrometheusRemoteWrite.
- Delete API DeletePrometheusRemoteWrite.
- Delete API GetPrometheusRemoteWrite.
- Delete API ListPrometheusRemoteWrites.
- Delete API UpdatePrometheusRemoteWrite.
- Update API CreateOrUpdateEventBridgeIntegration: update param Name.
- Update API CreateOrUpdateIMRobot: update param Type.
- Update API CreateOrUpdateSilencePolicy: add param EffectiveTimeType.
- Update API CreateOrUpdateSilencePolicy: add param TimePeriod.
- Update API CreateOrUpdateSilencePolicy: add param TimeSlots.
- Update API CreateOrUpdateSilencePolicy: update response param.
- Update API DeleteEventBridgeIntegration: update param Id.
- Update API GetPrometheusInstance: update response param.
- Update API GetRumAppInfo: update response param.
- Update API GetRumUploadFiles: add param VersionId.
- Update API ListAlerts: add param Owner.
- Update API ListEnvironments: add param FilterRegionIds.
- Update API ListSilencePolicies: update response param.
- Update API QueryCommercialUsage: update response param.


2024-08-05 Version: 6.0.0
- Delete API AddPrometheusRemoteWrite.
- Delete API DeletePrometheusRemoteWrite.
- Delete API GetPrometheusRemoteWrite.
- Delete API ListPrometheusRemoteWrites.
- Delete API UpdatePrometheusRemoteWrite.
- Update API CreateOrUpdateEventBridgeIntegration: update param Name.
- Update API CreateOrUpdateIMRobot: update param Type.
- Update API DeleteEventBridgeIntegration: update param Id.
- Update API GetPrometheusInstance: update response param.
- Update API GetRumUploadFiles: add param VersionId.
- Update API ListAlerts: add param Owner.
- Update API ListEnvironments: add param FilterRegionIds.
- Update API QueryCommercialUsage: update response param.


2024-07-24 Version: 5.0.0
- Support API DoInsightsAction.
- Support API GetRumOcuStatisticData.
- Update API CreateRumApp: add param NickName.
- Update API CreateRumApp: update param Tag.
- Update API CreateRumApp: update param Tag.
- Update API CreateRumApp: update response param.
- Update API DescribeEnvironment: update response param.
- Update API GetRumAppInfo: update response param.
- Update API GetRumApps: update param Tags.
- Update API GetRumApps: update param Tags.
- Update API UpdateRumApp: add param BonreeSDKConfigJson.
- Update API Upload: update param File.


2024-06-21 Version: 4.11.1
- Generated python 2019-08-08 for ARMS.

2024-06-20 Version: 4.11.0
- Support API GetTraceAppConfig.
- Update API CheckCommercialStatus: update param Service.
- Update API CreateOrUpdateNotificationPolicy: add param State.
- Update API CreateOrUpdateNotificationPolicy: update response param.
- Update API GetCommercialStatus: update param CommodityCode.
- Update API GetRetcodeAppByPid: update param Pid.
- Update API GetRumExceptionStack: add param SourcemapType.
- Update API ListNotificationPolicies: update response param.
- Update API Upload: update param File.


2024-06-20 Version: 4.11.0
- Support API GetTraceAppConfig.
- Update API CheckCommercialStatus: update param Service.
- Update API CreateOrUpdateNotificationPolicy: add param State.
- Update API CreateOrUpdateNotificationPolicy: update response param.
- Update API GetCommercialStatus: update param CommodityCode.
- Update API GetRetcodeAppByPid: update param Pid.
- Update API GetRumExceptionStack: add param SourcemapType.
- Update API ListNotificationPolicies: update response param.
- Update API Upload: update param File.


2024-06-17 Version: 4.10.7
- Update API CreateEnvironment: add param InitEnvironment.


2024-06-07 Version: 4.10.6
- Update API DeleteAddonRelease: add param AddonName.
- Update API ListAddons: update response param.


2024-06-05 Version: 4.10.5
- Generated python 2019-08-08 for ARMS.

2024-05-30 Version: 4.10.4
- Update API CreateEnvironment: add param GrafanaWorkspaceId.
- Update API DescribeEnvironment: update response param.
- Update API GetAlertRules: update response param.
- Update API GetPrometheusInstance: update response param.
- Update API GetTraceApp: update response param.


2024-05-27 Version: 4.10.3
- Update API CreateOrUpdateSilencePolicy: add param State.
- Update API CreateOrUpdateSilencePolicy: update response param.
- Update API GetPrometheusInstance: update response param.
- Update API ListSilencePolicies: update response param.


2024-05-23 Version: 4.10.2
- Update API DescribeEnvironmentFeature: update response param.
- Update API ListEnvironmentFeatures: add param AliyunLang.


2024-05-23 Version: 4.10.2
- Update API DescribeEnvironmentFeature: update response param.
- Update API ListEnvironmentFeatures: add param AliyunLang.


2024-05-11 Version: 4.10.1
- Update API ListAlertEvents: add param ShowNotificationPolicies.
- Update API ListAlertEvents: update response param.


2024-05-09 Version: 4.10.0
- Support API CreateRumApp.
- Support API CreateRumUploadFileUrl.
- Support API DeleteRumApp.
- Support API DeleteRumUploadFile.
- Support API GetRumAppInfo.
- Support API GetRumApps.
- Support API GetRumDataForPage.
- Support API GetRumExceptionStack.
- Support API GetRumUploadFiles.
- Support API UpdateRumApp.
- Support API UpdateRumFileStatus.
- Update API CreateEnvironment: update param EnvironmentSubType.
- Update API CreateOrUpdateContact: add param CorpUserId.
- Update API CreateOrUpdateContact: update response param.
- Update API DescribeIMRobots: update response param.


2024-05-07 Version: 4.9.0
- Support API UpdatePrometheusInstance.
- Update API CreateOrUpdateAlertRule: add param AutoAddTargetConfig.
- Update API CreateOrUpdateAlertRule: add param Product.
- Update API CreatePrometheusInstance: add param ArchiveDuration.
- Update API CreatePrometheusInstance: update param Duration.
- Update API CreateTimingSyntheticTask: update param CommonSetting.
- Update API DescribeEnvironmentFeature: add param AliyunLang.
- Update API DescribeEnvironmentFeature: update response param.
- Update API GetPrometheusInstance: update response param.
- Update API GetTimingSyntheticTask: update response param.
- Update API ListEnvironments: add param FeePackage.
- Update API ListEnvironments: update response param.
- Update API ListTimingSyntheticTasks: update response param.
- Update API TagResources: update param ResourceId.
- Update API UpdateTimingSyntheticTask: update param CommonSetting.


2024-04-12 Version: 4.8.0
- Support API UpdatePrometheusInstance.
- Update API CreatePrometheusInstance: add param ArchiveDuration.
- Update API CreatePrometheusInstance: update param Duration.
- Update API CreateTimingSyntheticTask: update param CommonSetting.
- Update API GetPrometheusInstance: update response param.
- Update API GetTimingSyntheticTask: update response param.
- Update API ListTimingSyntheticTasks: update response param.
- Update API TagResources: update param ResourceId.
- Update API UpdateTimingSyntheticTask: update param CommonSetting.


2024-04-03 Version: 4.7.4
- Update API DeleteAppList: update param Pids.
- Update API InitEnvironment: add param CreateAuthToken.
- Update API ListDashboards: update response param.
- Update API UpdateEnvironment: update param EnvironmentName.


2024-03-21 Version: 4.7.2
- Update API UpdateEnvironment: update param EnvironmentName.


2024-03-19 Version: 4.7.1
- Update API CreateEnvironment: add param FeePackage.
- Update API CreateTimingSyntheticTask: update param MonitorConf.
- Update API DescribeEnvironment: update response param.
- Update API GetTimingSyntheticTask: update response param.
- Update API UpdateEnvironment: add param EnvironmentName.
- Update API UpdateEnvironment: add param FeePackage.
- Update API UpdateEnvironment: update param EnvironmentName.
- Update API UpdateTimingSyntheticTask: update param MonitorConf.


2024-03-19 Version: 4.7.1
- Update API CreateEnvironment: add param FeePackage.
- Update API CreateTimingSyntheticTask: update param MonitorConf.
- Update API DescribeEnvironment: update response param.
- Update API GetTimingSyntheticTask: update response param.
- Update API UpdateEnvironment: add param EnvironmentName.
- Update API UpdateEnvironment: add param FeePackage.
- Update API UpdateEnvironment: update param EnvironmentName.
- Update API UpdateTimingSyntheticTask: update param MonitorConf.


2024-03-12 Version: 4.7.0
- Support API ListAddons.
- Support API ListSyntheticDetail.
- Update API CreateEnvironment: add param PrometheusInstanceId.
- Update API CreatePrometheusInstance: add param Duration.
- Update API CreateTimingSyntheticTask: update param CommonSetting.
- Update API CreateTimingSyntheticTask: update param MonitorConf.
- Update API DescribeEnvironment: update response param.
- Update API GetTimingSyntheticTask: update response param.
- Update API UpdateTimingSyntheticTask: update param CommonSetting.
- Update API UpdateTimingSyntheticTask: update param MonitorConf.
- Update API Upload: update response param.


2024-03-01 Version: 4.6.0
- Support API ListAddons.
- Update API CreateEnvironment: add param PrometheusInstanceId.
- Update API CreatePrometheusInstance: add param Duration.
- Update API CreateTimingSyntheticTask: update param CommonSetting.
- Update API CreateTimingSyntheticTask: update param MonitorConf.
- Update API DescribeEnvironment: update response param.
- Update API GetTimingSyntheticTask: update response param.
- Update API UpdateTimingSyntheticTask: update param CommonSetting.
- Update API UpdateTimingSyntheticTask: update param MonitorConf.
- Update API Upload: update response param.


2024-02-28 Version: 4.5.0
- Support API ListAddons.
- Update API CreateEnvironment: add param PrometheusInstanceId.
- Update API CreatePrometheusInstance: add param Duration.
- Update API CreateTimingSyntheticTask: update param CommonSetting.
- Update API DescribeEnvironment: update response param.
- Update API GetTimingSyntheticTask: update response param.
- Update API UpdateTimingSyntheticTask: update param CommonSetting.
- Update API Upload: update response param.


2024-02-23 Version: 4.4.0
- Support API ListAddons.
- Update API CreateEnvironment: add param PrometheusInstanceId.
- Update API CreateTimingSyntheticTask: update param CommonSetting.
- Update API GetTimingSyntheticTask: update response param.
- Update API UpdateTimingSyntheticTask: update param CommonSetting.
- Update API Upload: update response param.


2024-02-19 Version: 4.3.0
- Support API ListAddons.
- Update API Upload: update response param.


2024-01-30 Version: 4.2.1
- Update API CreateIntegrationadd RegionId param.
- Update API DescribeEnvironmentupdate response param.
- Update API ListEnvironmentsadd BindResourceId param.


2024-01-26 Version: 4.2.0
- Support API ListEnvironmentDashboards.


2024-01-23 Version: 4.1.2
- Generated python 2019-08-08 for ARMS.

2024-01-18 Version: 4.1.1
- Generated python 2019-08-08 for ARMS.

2024-01-16 Version: 4.1.0
- Generated python 2019-08-08 for ARMS.

2024-01-10 Version: 4.0.0
- Generated python 2019-08-08 for ARMS.

2024-01-05 Version: 3.12.0
- Generated python 2019-08-08 for ARMS.

2024-01-05 Version: 3.11.2
- Generated python 2019-08-08 for ARMS.

2023-12-21 Version: 3.11.1
- Generated python 2019-08-08 for ARMS.

2023-12-20 Version: 3.11.0
- Generated python 2019-08-08 for ARMS.

2023-12-14 Version: 3.10.1
- Generated python 2019-08-08 for ARMS.

2023-12-13 Version: 3.10.0
- Generated python 2019-08-08 for ARMS.

2023-12-06 Version: 3.9.0
- Generated python 2019-08-08 for ARMS.

2023-11-28 Version: 3.8.1
- Generated python 2019-08-08 for ARMS.

2023-11-27 Version: 3.8.0
- Generated python 2019-08-08 for ARMS.

2023-11-21 Version: 3.7.0
- Generated python 2019-08-08 for ARMS.

2023-11-16 Version: 3.6.1
- Generated python 2019-08-08 for ARMS.

2023-11-16 Version: 3.6.1
- Generated python 2019-08-08 for ARMS.

2023-11-13 Version: 3.6.0
- Generated python 2019-08-08 for ARMS.

2023-11-07 Version: 3.5.1
- Generated python 2019-08-08 for ARMS.

2023-11-03 Version: 3.5.0
- Generated python 2019-08-08 for ARMS.

2023-10-26 Version: 3.4.0
- Generated python 2019-08-08 for ARMS.

2023-10-16 Version: 3.3.0
- Generated python 2019-08-08 for ARMS.

2023-09-14 Version: 3.2.1
- Generated python 2019-08-08 for ARMS.

2023-09-11 Version: 3.2.0
- Generated python 2019-08-08 for ARMS.

2023-08-30 Version: 3.1.0
- Generated python 2019-08-08 for ARMS.

2023-08-24 Version: 3.0.1
- Generated python 2019-08-08 for ARMS.

2023-08-23 Version: 3.0.0
- Generated python 2019-08-08 for ARMS.

2023-08-12 Version: 2.1.1
- Generated python 2019-08-08 for ARMS.

2023-08-09 Version: 2.1.0
- Generated python 2019-08-08 for ARMS.

2023-08-04 Version: 2.0.4
- Generated python 2019-08-08 for ARMS.

2023-08-02 Version: 2.0.3
- Api update.

2023-08-01 Version: 2.0.2
- Api update.

2023-07-28 Version: 2.0.1
- Api update.

2023-07-14 Version: 2.0.0
- Api update.

2023-03-07 Version: 1.0.4
- Fixed bugs for getClusterAllUrl pop interface.

2022-09-05 Version: 1.0.3
- Update sdk.

2022-05-30 Version: 1.0.2
- Arms AlertManager DescribeWebhookContacts.

2022-05-23 Version: 1.0.1
- RegisterCloudProduct.

2020-12-29 Version: 1.0.0
- AMP Version Change.

